@@ -24,7 +24,7 @@
 try:
     from collections import OrderedDict
 except:
-    import OrderedDict
+        import ordereddict as OrderedDict
 import logging
 from multiprocessing import Lock
 import sys
